// Copyright 2016 Dietrich Epp.
// This file is part of the Moria Gamedev Repository.  This file is licensed
// under the terms of the MIT license.  For more information, see LICENSE.txt.
'use strict';

var Width = 26;

var ClickDelay = 250;

function font() {
	var font =Game.add.retroFont(
		'font', 28, 40, Phaser.RetroFont.TEXT_SET1,
		16, 4, 0);
	font.autoUpperCase = false;
	font.multiLine = true;
	return font;
}

function Text() {
	this.font = font();
	this.image = Game.add.image(400, 400, this.font);
	this.image.anchor.set(0.5, 0.5);
	this.image.fixedToCamera = true;
	this.callback = null;
	this.delayTime = -1;
	this.input = Game.input.keyboard.addKey(Phaser.Keyboard.SPACEBAR);
}

Text.prototype.create = function() {};

Text.prototype.showText = function(text, callback) {
	var words = text.split(/ +/);
	var lines = [];
	var line = [];
	var pos = -1;
	for (var i = 0; i < words.length; i++) {
		var word = words[i];
		if (word === '') {
			continue;
		}
		if (line !== null && pos + 1 + word.length > Width) {
			lines.push(line.join(' '));
			line = [];
			pos = -1;
		}
		line.push(word);
		pos += 1 + word.length;
	}
	if (line.length) {
		lines.push(line.join(' '));
	}
	this.font.text = lines.join('\n');
	this.image.visible = true;
	this.callback = callback;
	this.delayTime = Game.time.now + ClickDelay;
};

Text.prototype.update = function() {
	if (!this.callback) {
		return;
	}
	var now = Game.time.now;
	if (now > this.delayTime && this.input.isDown) {
		this.image.visible = false;
		this.callback.call(null);
		this.callback = null;
	}
};

module.exports = {
	Text: Text,
	font: font,
};
