// Copyright 2016 Dietrich Epp.
// This file is part of the Moria Gamedev Repository.  This file is licensed
// under the terms of the MIT license.  For more information, see LICENSE.txt.
'use strict';
var vars;

function error(msg) {
	console.error(msg);
}

function warn(msg) {
	console.warn(msg);
}

function getVar(name) {
	if (vars === undefined) {
		vars = {};
		var s = window.location.hash;
		if (s !== '') {
			var parts = s.substr(1).split(';');
			for (var i = 0; i < parts.length; i++) {
				var part = parts[i];
				var eq = part.indexOf('=');
				if (eq >= 0) {
					var vname = part.substring(0, eq);
					var vval = part.substring(eq + 1);
					vars[vname] = vval;
				} else {
					vars[part] = null;
				}
			}
		}
	}
	return vars[name];
}

function hasVar(name) {
	return getVar(name) !== undefined;
}

function randomDelta() {
	var r = Math.random();
	if (r > 0.3) {
		return 0;
	} else if (r > 0.15) {
		return +1;
	} else {
		return -1;
	}
}

function randomOffset(sprite, x, y) {
	sprite.x = x + randomDelta() * 4;
	sprite.y = y + randomDelta() * 4;
}

function randomFrame(sprite, frames) {
	var r;
	r = Math.min((Math.random() * frames.length) | 0, frames.length - 1);
	sprite.frameName = frames[r];
	r = (Math.random() * 4) | 0;
	sprite.scale.set(r & 1 ? +1 : -1, r & 2 ? +1 : -1);
}

module.exports = {
	error: error,
	warn: warn,
	getVar: getVar,
	hasVar: hasVar,
	randomOffset: randomOffset,
	randomFrame: randomFrame,
};
